==> tool-sql-1.1.10-sources.jar: io/ciera/tool/sql/ooaofooa/statemachine/impl/MealyActionHomeSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.statemachine.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.statemachine.ActionHomeSet;
import io.ciera.tool.sql.ooaofooa.statemachine.MealyActionHome;
import io.ciera.tool.sql.ooaofooa.statemachine.MealyActionHomeSet;
import io.ciera.tool.sql.ooaofooa.statemachine.MealyStateMachineSet;
import io.ciera.tool.sql.ooaofooa.statemachine.TransitionSet;
import io.ciera.tool.sql.ooaofooa.statemachine.impl.ActionHomeSetImpl;
import io.ciera.tool.sql.ooaofooa.statemachine.impl.MealyStateMachineSetImpl;
import io.ciera.tool.sql.ooaofooa.statemachine.impl.TransitionSetImpl;

import java.util.Arrays;
import java.util.List;


public class MealyActionHomeSetImpl extends InstanceSet<MealyActionHomeSet,MealyActionHome> implements MealyActionHomeSet {

    // attributes
    @Override
    public void setSM_ID( UniqueId ref_SM_ID ) throws XtumlException {
        for ( MealyActionHome mealyactionhome : this ) mealyactionhome.setSM_ID( ref_SM_ID );
    }
    @Override
    public void setTrans_ID( UniqueId ref_Trans_ID ) throws XtumlException {
        for ( MealyActionHome mealyactionhome : this ) mealyactionhome.setTrans_ID( ref_Trans_ID );
    }
    @Override
    public void setAct_ID( UniqueId ref_Act_ID ) throws XtumlException {
        for ( MealyActionHome mealyactionhome : this ) mealyactionhome.setAct_ID( ref_Act_ID );
    }


    // selections
    @Override
    public MealyStateMachineSet R512_MealyStateMachine() throws XtumlException {
        MealyStateMachineSet mealystatemachineset = new MealyStateMachineSetImpl();
        for ( MealyActionHome mealyactionhome : this ) mealystatemachineset.add( mealyactionhome.R512_MealyStateMachine() );
        return mealystatemachineset;
    }
    @Override
    public TransitionSet R512_Transition() throws XtumlException {
        TransitionSet transitionset = new TransitionSetImpl();
        for ( MealyActionHome mealyactionhome : this ) transitionset.add( mealyactionhome.R512_Transition() );
        return transitionset;
    }
    @Override
    public ActionHomeSet R513_is_a_ActionHome() throws XtumlException {
        ActionHomeSet actionhomeset = new ActionHomeSetImpl();
        for ( MealyActionHome mealyactionhome : this ) actionhomeset.add( mealyactionhome.R513_is_a_ActionHome() );
        return actionhomeset;
    }


    @Override
    public MealyActionHome nullElement() {
        return MealyActionHomeImpl.EMPTY_MEALYACTIONHOME;
    }

    @Override
    public MealyActionHomeSet emptySet() {
      return new MealyActionHomeSetImpl();
    }

    @Override
    public MealyActionHomeSet value() {
        return this;
    }

    @Override
    public List<MealyActionHome> elements() {
        return Arrays.asList(toArray(new MealyActionHome[0]));
    }

}

==> tool-sql-1.1.11-sources.jar: io/ciera/tool/sql/ooaofooa/statemachine/impl/MealyActionHomeSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.statemachine.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.statemachine.ActionHomeSet;
import io.ciera.tool.sql.ooaofooa.statemachine.MealyActionHome;
import io.ciera.tool.sql.ooaofooa.statemachine.MealyActionHomeSet;
import io.ciera.tool.sql.ooaofooa.statemachine.MealyStateMachineSet;
import io.ciera.tool.sql.ooaofooa.statemachine.TransitionSet;
import io.ciera.tool.sql.ooaofooa.statemachine.impl.ActionHomeSetImpl;
import io.ciera.tool.sql.ooaofooa.statemachine.impl.MealyStateMachineSetImpl;
import io.ciera.tool.sql.ooaofooa.statemachine.impl.TransitionSetImpl;

import java.util.Arrays;
import java.util.Comparator;
import java.util.List;


public class MealyActionHomeSetImpl extends InstanceSet<MealyActionHomeSet,MealyActionHome> implements MealyActionHomeSet {

    public MealyActionHomeSetImpl() {
    }

    public MealyActionHomeSetImpl(Comparator<? super MealyActionHome> comp) {
        super(comp);
    }

    // attributes
    @Override
    public void setAct_ID( UniqueId ref_Act_ID ) throws XtumlException {
        for ( MealyActionHome mealyactionhome : this ) mealyactionhome.setAct_ID( ref_Act_ID );
    }
    @Override
    public void setTrans_ID( UniqueId ref_Trans_ID ) throws XtumlException {
        for ( MealyActionHome mealyactionhome : this ) mealyactionhome.setTrans_ID( ref_Trans_ID );
    }
    @Override
    public void setSM_ID( UniqueId ref_SM_ID ) throws XtumlException {
        for ( MealyActionHome mealyactionhome : this ) mealyactionhome.setSM_ID( ref_SM_ID );
    }


    // selections
    @Override
    public MealyStateMachineSet R512_MealyStateMachine() throws XtumlException {
        MealyStateMachineSet mealystatemachineset = new MealyStateMachineSetImpl();
        for ( MealyActionHome mealyactionhome : this ) mealystatemachineset.add( mealyactionhome.R512_MealyStateMachine() );
        return mealystatemachineset;
    }
    @Override
    public TransitionSet R512_Transition() throws XtumlException {
        TransitionSet transitionset = new TransitionSetImpl();
        for ( MealyActionHome mealyactionhome : this ) transitionset.add( mealyactionhome.R512_Transition() );
        return transitionset;
    }
    @Override
    public ActionHomeSet R513_is_a_ActionHome() throws XtumlException {
        ActionHomeSet actionhomeset = new ActionHomeSetImpl();
        for ( MealyActionHome mealyactionhome : this ) actionhomeset.add( mealyactionhome.R513_is_a_ActionHome() );
        return actionhomeset;
    }


    @Override
    public MealyActionHome nullElement() {
        return MealyActionHomeImpl.EMPTY_MEALYACTIONHOME;
    }

    @Override
    public MealyActionHomeSet emptySet() {
      return new MealyActionHomeSetImpl();
    }

    @Override
    public MealyActionHomeSet emptySet(Comparator<? super MealyActionHome> comp) {
      return new MealyActionHomeSetImpl(comp);
    }

    @Override
    public MealyActionHomeSet value() {
        return this;
    }

    @Override
    public List<MealyActionHome> elements() {
        return Arrays.asList(toArray(new MealyActionHome[0]));
    }

}
